@@ -1,7 +1,7 @@
 -module(diameter_dict_parser).
 -export([parse/1, parse_and_scan/1, format_error/1]).
 
--file("/net/isildur/ldisk/daily_build/19_prebuild_master-opu_o.2016-06-21_20/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/net/isildur/ldisk/daily_build/19_prebuild_opu_o.2016-12-12_21/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
@@ -1200,9 +1200,11 @@ yeccpars2_131(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_131_(Stack),
  yeccgoto_sections(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_application_id/7}).
 yeccgoto_application_id(72, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_78(78, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp/7}).
 yeccgoto_avp(40, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_44(44, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp(44, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1212,33 +1214,41 @@ yeccgoto_avp(66, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_avp(94, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_44(44, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_code/7}).
 yeccgoto_avp_code(100, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_101(101, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_def/7}).
 yeccgoto_avp_def(4, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_123(123, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_def(123, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_123(123, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_defs/7}).
 yeccgoto_avp_defs(4=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_122(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_defs(123=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_124(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_flags/7}).
 yeccgoto_avp_flags(127=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_129(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_header/7}).
 yeccgoto_avp_header(93, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_94(94, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_header_tok/7}).
 yeccgoto_avp_header_tok(95, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_96(96, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_name/7}).
 yeccgoto_avp_name(47, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_57(57, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_name(49, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_52(52, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_names/7}).
 yeccgoto_avp_names(82=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_86(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_names(115=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1248,6 +1258,7 @@ yeccgoto_avp_names(117=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_avp_names(119=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_120(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_ref/7}).
 yeccgoto_avp_ref(40=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_43(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_ref(41=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1259,6 +1270,7 @@ yeccgoto_avp_ref(66=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_avp_ref(94=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_43(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_spec/7}).
 yeccgoto_avp_spec(46, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_59(59, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avp_spec(47=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1266,12 +1278,15 @@ yeccgoto_avp_spec(47=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_avp_spec(49=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_51(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_type/7}).
 yeccgoto_avp_type(125, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_127(127, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avp_vendor/7}).
 yeccgoto_avp_vendor(101, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_103(103, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_avps/7}).
 yeccgoto_avps(40=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_42(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_avps(44=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1281,22 +1296,27 @@ yeccgoto_avps(66=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_avps(94=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_106(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_bit/7}).
 yeccgoto_bit(73, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_74(74, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_bits/7}).
 yeccgoto_bits(70, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_72(72, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_bits(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_77(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_command_def/7}).
 yeccgoto_command_def(13, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_25(25, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_command_def(25, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_25(25, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_command_id/7}).
 yeccgoto_command_id(69, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_70(70, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_diameter_name/7}).
 yeccgoto_diameter_name(13, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_24(24, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_diameter_name(25, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1308,9 +1328,11 @@ yeccgoto_diameter_name(47=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_diameter_name(49=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_50(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_dictionary/7}).
 yeccgoto_dictionary(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_3(3, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_enum_def/7}).
 yeccgoto_enum_def(107, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_110(110, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_enum_def(110, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1318,6 +1340,7 @@ yeccgoto_enum_def(110, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_enum_def(113, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_110(110, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_enum_defs/7}).
 yeccgoto_enum_defs(107=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_109(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_enum_defs(110=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1325,24 +1348,29 @@ yeccgoto_enum_defs(110=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_enum_defs(113=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_114(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_group_def/7}).
 yeccgoto_group_def(10, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_91(91, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_group_def(91, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_91(91, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_group_defs/7}).
 yeccgoto_group_defs(10=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_90(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_group_defs(91=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_92(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_header/7}).
 yeccgoto_header(65, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_66(66, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_header_tok/7}).
 yeccgoto_header_tok(28, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_29(29, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_header_tok(67, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_68(68, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_ident/7}).
 yeccgoto_ident(4, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_121(121, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_ident(6=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1398,6 +1426,7 @@ yeccgoto_ident(125=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_ident(127=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_128(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_idents/7}).
 yeccgoto_idents(82=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_84(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_idents(85=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1409,11 +1438,13 @@ yeccgoto_idents(117=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_idents(119=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_84(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_message_defs/7}).
 yeccgoto_message_defs(13=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_22(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_message_defs(25=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_64(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_module/7}).
 yeccgoto_module(6, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_117(117, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_module(7, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1421,6 +1452,7 @@ yeccgoto_module(7, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_module(12, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_82(82, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_qual/7}).
 yeccgoto_qual(40, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_41(41, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_qual(44, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1430,11 +1462,13 @@ yeccgoto_qual(66, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_qual(94, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_41(41, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_section/7}).
 yeccgoto_section(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_2(2, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_section(2, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_2(2, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_sections/7}).
 yeccgoto_sections(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_1(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_sections(2=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
