@@ -9,7 +9,7 @@
 -include("megaco_text_mini_parser.hrl").
 
 
--file("/net/isildur/ldisk/daily_build/19_prebuild_master-opu_o.2016-06-21_20/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/net/isildur/ldisk/daily_build/19_prebuild_opu_o.2016-12-12_21/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
@@ -1437,9 +1437,11 @@ yeccpars2_116(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_116_(Stack),
  yeccgoto_mId(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_authenticationHeader/7}).
 yeccgoto_authenticationHeader(1, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_4(4, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_daddr/7}).
 yeccgoto_daddr(94, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_96(96, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_daddr(95=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1447,27 +1449,35 @@ yeccgoto_daddr(95=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_daddr(97=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_98(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_deviceName/7}).
 yeccgoto_deviceName(89, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_113(113, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_domainAddress/7}).
 yeccgoto_domainAddress(86=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_92(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_domainName/7}).
 yeccgoto_domainName(86=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_91(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_mId/7}).
 yeccgoto_mId(86=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_90(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_megacoMessage/7}).
 yeccgoto_megacoMessage(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_2(2, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_message/7}).
 yeccgoto_message(4, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_87(87, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_mtpAddress/7}).
 yeccgoto_mtpAddress(89, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_112(112, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_optSep/7}).
 yeccgoto_optSep(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_1(1, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_optSep(84=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1483,14 +1493,17 @@ yeccgoto_optSep(112=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_optSep(113=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_115(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_pathName/7}).
 yeccgoto_pathName(89=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_111(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_portNumber/7}).
 yeccgoto_portNumber(100, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_102(102, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_portNumber(107, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_108(108, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_safeToken/7}).
 yeccgoto_safeToken(4, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_86(86, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_safeToken(6, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1514,6 +1527,7 @@ yeccgoto_safeToken(100=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_safeToken(107=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_101(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_safeToken2/7}).
 yeccgoto_safeToken2(4=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_7(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_safeToken2(6=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
