@@ -197,7 +197,7 @@ name_it(intersection)  -> ' * ';
 name_it(difference)    -> ' - ';
 name_it(Name) -> Name.   
 
--file("/net/isildur/ldisk/daily_build/19_prebuild_master-opu_o.2016-06-21_20/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/net/isildur/ldisk/daily_build/19_prebuild_opu_o.2016-12-12_21/otp_src_19/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
@@ -1129,6 +1129,7 @@ yeccpars2_79(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_79_(Stack),
  yeccgoto_statement(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_add_op/7}).
 yeccgoto_add_op(11, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(45, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_add_op(39, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1150,9 +1151,11 @@ yeccgoto_add_op(61, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_add_op(79, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(45, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_assign_op/7}).
 yeccgoto_assign_op(2, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(76, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_cast_op/7}).
 yeccgoto_cast_op(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(15, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_cast_op(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1176,6 +1179,7 @@ yeccgoto_cast_op(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_cast_op(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(15, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_const/7}).
 yeccgoto_const(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_14(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_const(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1205,6 +1209,7 @@ yeccgoto_const(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_const(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_14(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_constant/7}).
 yeccgoto_constant(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_13(13, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_constant(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1234,6 +1239,7 @@ yeccgoto_constant(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_constant(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_13(13, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_constants/7}).
 yeccgoto_constants(26, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_27(27, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_constants(29=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1241,6 +1247,7 @@ yeccgoto_constants(29=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_constants(34, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_35(35, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_count_op/7}).
 yeccgoto_count_op(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(12, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_count_op(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1264,6 +1271,7 @@ yeccgoto_count_op(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_count_op(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(12, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_expr/7}).
 yeccgoto_expr(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_11(11, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_expr(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1287,6 +1295,7 @@ yeccgoto_expr(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_expr(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_79(79, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_id/7}).
 yeccgoto_id(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_id(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1318,6 +1327,7 @@ yeccgoto_id(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_id(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_mult_op/7}).
 yeccgoto_mult_op(11, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(44, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_mult_op(39, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1339,6 +1349,7 @@ yeccgoto_mult_op(61, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_mult_op(79, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(44, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_path_op/7}).
 yeccgoto_path_op(11, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(43, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_path_op(39, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1360,6 +1371,7 @@ yeccgoto_path_op(61, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_path_op(79, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(43, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_prefix_op/7}).
 yeccgoto_prefix_op(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(9, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_prefix_op(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1383,6 +1395,7 @@ yeccgoto_prefix_op(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_prefix_op(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(9, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_regatom/7}).
 yeccgoto_regatom(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_8(8, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_regatom(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1408,6 +1421,7 @@ yeccgoto_regatom(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_regatom(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_8(8, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_regexp/7}).
 yeccgoto_regexp(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_7(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_regexp(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1431,9 +1445,11 @@ yeccgoto_regexp(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_regexp(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_7(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_regint/7}).
 yeccgoto_regint(67, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_70(70, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_regstr/7}).
 yeccgoto_regstr(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_6(6, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_regstr(9, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1461,6 +1477,7 @@ yeccgoto_regstr(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_regstr(76, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_6(6, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_regvar/7}).
 yeccgoto_regvar(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_5(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_regvar(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1488,6 +1505,7 @@ yeccgoto_regvar(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_regvar(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_5(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_restr_op/7}).
 yeccgoto_restr_op(11, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(42, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_restr_op(39, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1509,16 +1527,19 @@ yeccgoto_restr_op(61, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_restr_op(79, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_0(42, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_statement/7}).
 yeccgoto_statement(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_4(4, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_statement(74, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_4(4, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_statements/7}).
 yeccgoto_statements(0=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_3(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_statements(74=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_75(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_type/7}).
 yeccgoto_type(6=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_73(_S, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_type(13=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1530,6 +1551,7 @@ yeccgoto_type(36=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_type(70=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_72(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_variable/7}).
 yeccgoto_variable(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_2(2, Cat, Ss, Stack, T, Ts, Tzr);
 yeccgoto_variable(9=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -1557,6 +1579,7 @@ yeccgoto_variable(74, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_variable(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_38(_S, Cat, Ss, Stack, T, Ts, Tzr).
 
+-dialyzer({nowarn_function, yeccgoto_xref/7}).
 yeccgoto_xref(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_1(1, Cat, Ss, Stack, T, Ts, Tzr).
 
